@@ -43,7 +43,7 @@ class LoadData:
 
     def write_data(self, data_list, cache=True):
         self.cache_data.extend(data_list)
-        if cache and len(self.cache_data) < 10000:
+        if cache and len(self.cache_data) < 1000:
             return
         if len(self.cache_data) == 0:
             return
@@ -90,8 +90,9 @@ class LoadDataKline(LoadData):
 class LoadTradeKline(LoadData):
     def __init__(self, *args, **kwargs):
         super(LoadTradeKline, self).__init__(*args, **kwargs)
-        self.csv_writer = csv.DictWriter(open(self.csv_path, mode="w"), delimiter=",",
-                                         fieldnames=["symbol", "id", "timestamp", "side", "price", "amount"])
+        self.csv_file = open(self.csv_path, mode="w")
+        self.csv_writer = csv.DictWriter(self.csv_file, delimiter=",", fieldnames=[
+                                         "symbol", "id", "timestamp", "side", "price", "amount"])
         self.csv_writer.writeheader()
 
     def load_close(self):
@@ -99,6 +100,7 @@ class LoadTradeKline(LoadData):
 
     def _write(self, data_list):
         self.csv_writer.writerows(data_list)
+        self.csv_file.flush()
 
     def load(self, symbol, pbr, *args, **kwargs):
         unix_temp = self.unix_start
@@ -122,7 +124,7 @@ class LoadTradeKline(LoadData):
                 result = [{
                     'symbol': trade['symbol'],
                     'id': trade['id'].replace('\n', ''),
-                    'timestamp': trade['timestamp'] - self.unix_start,
+                    'timestamp': int(trade['timestamp']) - self.unix_start,
                     'side': trade['side'],
                     'price': trade['price'],
                     'amount': trade['amount'],
